@@ -8,14 +8,18 @@ print STDERR "Processing sample 1-2\n";
     [    1,    2,    5,    6,    3,  1.5,    1,     3,     4]
 );
 
-$my_graph = new GIFgraph::bars( );
+$my_graph = new GIFgraph::bars();
 
-$my_graph->set( 'x_label' => 'X Label',
-                'y_label' => 'Y label',
-                'title' => 'Two data sets',
-                'y_max_value' => 40,
-                'y_tick_number' => 8,
-                'y_label_skip' => 2 );
+$my_graph->set( 
+	'x_label' => 'X Label',
+	'y_label' => 'Y label',
+	'title' => 'Two data sets',
+	'y_max_value' => 40,
+	'y_tick_number' => 8,
+	'y_label_skip' => 2,
+);
+
+$my_graph->set_legend( 'Data set 1', 'Data set 2' );
 
 $my_graph->plot_to_gif( "sample12.gif", \@data );
 
